@@ -1,6 +1,6 @@
-from dagmc_geometry_slice_plotter import plot_slice_of_dagmc_geometry
+from dagmc_geometry_slice_plotter import plot_slice
 
-plot = plot_slice_of_dagmc_geometry(
+plot = plot_slice(
     dagmc_file_or_trimesh_object="dagmc.h5m",
     plane_normal=[0, 1, 0],
     rotate_plot=45,
